==> 0.1.3.tar.gz: lib/yundian_alive_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'yundian_alive_method_channel.dart';

abstract class YundianAlivePlatform extends PlatformInterface {
  /// Constructs a YundianAlivePlatform.
  YundianAlivePlatform() : super(token: _token);

  static final Object _token = Object();

  static YundianAlivePlatform _instance = MethodChannelYundianAlive();

  /// The default instance of [YundianAlivePlatform] to use.
  ///
  /// Defaults to [MethodChannelYundianAlive].
  static YundianAlivePlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [YundianAlivePlatform] when
  /// they register themselves.
  static set instance(YundianAlivePlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> aliveEncryptAes(Map map) {
    throw UnimplementedError('aliveEncryptAes() has not been implemented.');
  }

  Future<String?> aliveInit(bool isDebug, String appKey, String mchInfo, String riskInfo) {
    throw UnimplementedError('aliveInit() has not been implemented.');
  }

  Future<String?> aliveStartDetect(String authToken, double distance, bool hasResultPage) {
    throw UnimplementedError('aliveStartDetect() has not been implemented.');
  }

  onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    throw UnimplementedError('onAliveResultListener() has not been implemented.');
  }

  Future<String?> aliveRelease() {
    throw UnimplementedError('aliveRelease() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedId(String layoutIdName) {
    throw UnimplementedError('aliveLayoutAliveDetectedId() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedFailId(String layoutIdName) {
    throw UnimplementedError('aliveLayoutDetectedFailId() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedPreId(String layoutIdName) {
    throw UnimplementedError('setLayoutAliveDetectedPreId() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedSuccessId(String layoutIdName) {
    throw UnimplementedError('setLayoutAliveDetectedSuccessId() has not been implemented.');
  }

  Future<String?> setTimeout(int timeout) {
    throw UnimplementedError('aliveTimeout() has not been implemented.');
  }

  Future<String?> setActionSize(int actionSize) {
    throw UnimplementedError('setActionSize() has not been implemented.');
  }

  Future<String?> setSecurityLevel(int securityLevel) {
    throw UnimplementedError('setSecurityLevel() has not been implemented.');
  }

  Future<String?> setActionSecond(int actionSecond) {
    throw UnimplementedError('setActionSecond() has not been implemented.');
  }

  Future<String?> setActionTps(String blinkEyes, String turnHeadNod, String openMouth, String shakeHead) {
    throw UnimplementedError('actionTps() has not been implemented.');
  }
}

==> 0.1.7.tar.gz: lib/yundian_alive_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'yundian_alive_method_channel.dart';

abstract class YundianAlivePlatform extends PlatformInterface {
  /// Constructs a YundianAlivePlatform.
  YundianAlivePlatform() : super(token: _token);

  static final Object _token = Object();

  static YundianAlivePlatform _instance = MethodChannelYundianAlive();

  /// The default instance of [YundianAlivePlatform] to use.
  ///
  /// Defaults to [MethodChannelYundianAlive].
  static YundianAlivePlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [YundianAlivePlatform] when
  /// they register themselves.
  static set instance(YundianAlivePlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> aliveEncryptAes(Map map) {
    throw UnimplementedError('aliveEncryptAes() has not been implemented.');
  }

  Future<String?> aliveInit(bool isDebug, String appKey, String mchInfo, String riskInfo) {
    throw UnimplementedError('aliveInit() has not been implemented.');
  }

  Future<String?> aliveStartDetect(String authToken, double distance, bool hasResultPage, bool hasPrePage) {
    throw UnimplementedError('aliveStartDetect() has not been implemented.');
  }

  onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    throw UnimplementedError('onAliveResultListener() has not been implemented.');
  }

  Future<String?> aliveRelease() {
    throw UnimplementedError('aliveRelease() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedId(String layoutIdName) {
    throw UnimplementedError('aliveLayoutAliveDetectedId() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedFailId(String layoutIdName) {
    throw UnimplementedError('aliveLayoutDetectedFailId() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedPreId(String layoutIdName) {
    throw UnimplementedError('setLayoutAliveDetectedPreId() has not been implemented.');
  }

  Future<String?> setLayoutAliveDetectedSuccessId(String layoutIdName) {
    throw UnimplementedError('setLayoutAliveDetectedSuccessId() has not been implemented.');
  }

  Future<String?> setTimeout(int timeout) {
    throw UnimplementedError('aliveTimeout() has not been implemented.');
  }

  Future<String?> setActionSize(int actionSize) {
    throw UnimplementedError('setActionSize() has not been implemented.');
  }

  Future<String?> setSecurityLevel(int securityLevel) {
    throw UnimplementedError('setSecurityLevel() has not been implemented.');
  }

  Future<String?> setActionSecond(int actionSecond) {
    throw UnimplementedError('setActionSecond() has not been implemented.');
  }

  Future<String?> setActionTps(String blinkEyes, String turnHeadNod, String openMouth, String shakeHead) {
    throw UnimplementedError('actionTps() has not been implemented.');
  }

  Future<String?> setLanguage(String language) {
    throw UnimplementedError('setLanguage() has not been implemented.');
  }
}
